@@ -2,7 +2,7 @@ import asyncio
 import time
 from pathlib import Path
 from typing import Any, List, Type
-from orionis.console.base.contracts.scheduler import IBaseScheduler
+from orionis.console.contracts.scheduler import IBaseScheduler
 from orionis.console.base.scheduler import BaseScheduler
 from orionis.container.container import Container
 from orionis.container.contracts.service_provider import IServiceProvider
@@ -123,6 +123,9 @@ class Application(Container, IApplication):
             # Property to store the exception handler class
             self.__exception_handler: Type[BaseExceptionHandler] = None
 
+            # Base path for the application, used for relative paths
+            self.__bootstrap_base_path: str | Path = None
+
             # Flag to prevent re-initialization
             self.__initialized = True
 
@@ -623,62 +626,89 @@ class Application(Container, IApplication):
         configuration system.
         """
 
+        # Convert dataclass instances to dictionaries
+        from orionis.services.introspection.dataclass.attributes import attributes
+
         # Load app configurator
+        if (isinstance(app, type) and issubclass(app, App)):
+            app = attributes(app)
         if not isinstance(app, (App, dict)):
             raise OrionisTypeError(f"Expected App instance or dict, got {type(app).__name__}")
         self.loadConfigApp(app)
 
         # Load auth configurator
+        if (isinstance(auth, type) and issubclass(auth, Auth)):
+            auth = attributes(auth)
         if not isinstance(auth, (Auth, dict)):
             raise OrionisTypeError(f"Expected Auth instance or dict, got {type(auth).__name__}")
         self.loadConfigAuth(auth)
 
         # Load cache configurator
+        if (isinstance(cache, type) and issubclass(cache, Cache)):
+            cache = attributes(cache)
         if not isinstance(cache, (Cache, dict)):
             raise OrionisTypeError(f"Expected Cache instance or dict, got {type(cache).__name__}")
         self.loadConfigCache(cache)
 
         # Load cors configurator
+        if (isinstance(cors, type) and issubclass(cors, Cors)):
+            cors = attributes(cors)
         if not isinstance(cors, (Cors, dict)):
             raise OrionisTypeError(f"Expected Cors instance or dict, got {type(cors).__name__}")
         self.loadConfigCors(cors)
 
         # Load database configurator
+        if (isinstance(database, type) and issubclass(database, Database)):
+            database = attributes(database)
         if not isinstance(database, (Database, dict)):
             raise OrionisTypeError(f"Expected Database instance or dict, got {type(database).__name__}")
         self.loadConfigDatabase(database)
 
         # Load filesystems configurator
+        if (isinstance(filesystems, type) and issubclass(filesystems, Filesystems)):
+            filesystems = attributes(filesystems)
         if not isinstance(filesystems, (Filesystems, dict)):
             raise OrionisTypeError(f"Expected Filesystems instance or dict, got {type(filesystems).__name__}")
         self.loadConfigFilesystems(filesystems)
 
         # Load logging configurator
+        if (isinstance(logging, type) and issubclass(logging, Logging)):
+            logging = attributes(logging)
         if not isinstance(logging, (Logging, dict)):
             raise OrionisTypeError(f"Expected Logging instance or dict, got {type(logging).__name__}")
         self.loadConfigLogging(logging)
 
         # Load mail configurator
+        if (isinstance(mail, type) and issubclass(mail, Mail)):
+            mail = attributes(mail)
         if not isinstance(mail, (Mail, dict)):
             raise OrionisTypeError(f"Expected Mail instance or dict, got {type(mail).__name__}")
         self.loadConfigMail(mail)
 
         # Load paths configurator
+        if (isinstance(path, type) and issubclass(path, Paths)):
+            path = attributes(path)
         if not isinstance(path, (Paths, dict)):
             raise OrionisTypeError(f"Expected Paths instance or dict, got {type(path).__name__}")
         self.loadPaths(path)
 
         # Load queue configurator
+        if (isinstance(queue, type) and issubclass(queue, Queue)):
+            queue = attributes(queue)
         if not isinstance(queue, (Queue, dict)):
             raise OrionisTypeError(f"Expected Queue instance or dict, got {type(queue).__name__}")
         self.loadConfigQueue(queue)
 
         # Load session configurator
+        if (isinstance(session, type) and issubclass(session, Session)):
+            session = attributes(session)
         if not isinstance(session, (Session, dict)):
             raise OrionisTypeError(f"Expected Session instance or dict, got {type(session).__name__}")
         self.loadConfigSession(session)
 
         # Load testing configurator
+        if (isinstance(testing, type) and issubclass(testing, Testing)):
+            testing = attributes(testing)
         if not isinstance(testing, (Testing, dict)):
             raise OrionisTypeError(f"Expected Testing instance or dict, got {type(testing).__name__}")
         self.loadConfigTesting(testing)
@@ -764,7 +794,9 @@ class Application(Container, IApplication):
 
         # If app is a dict, convert it to App instance
         if isinstance(app, dict):
-            app = App(**app)
+            app = App(**app).toDict()
+        elif isinstance(app, App):
+            app = app.toDict()
 
         # Store the configuration
         self.__configurators['app'] = app
@@ -850,7 +882,9 @@ class Application(Container, IApplication):
 
         # If auth is a dict, convert it to Auth instance
         if isinstance(auth, dict):
-            auth = Auth(**auth)
+            auth = Auth(**auth).toDict()
+        elif isinstance(auth, Auth):
+            auth = auth.toDict()
 
         # Store the configuration
         self.__configurators['auth'] = auth
@@ -936,7 +970,9 @@ class Application(Container, IApplication):
 
         # If cache is a dict, convert it to Cache instance
         if isinstance(cache, dict):
-            cache = Cache(**cache)
+            cache = Cache(**cache).toDict()
+        elif isinstance(cache, Cache):
+            cache = cache.toDict()
 
         # Store the configuration
         self.__configurators['cache'] = cache
@@ -1022,7 +1058,9 @@ class Application(Container, IApplication):
 
         # If cors is a dict, convert it to Cors instance
         if isinstance(cors, dict):
-            cors = Cors(**cors)
+            cors = Cors(**cors).toDict()
+        elif isinstance(cors, Cors):
+            cors = cors.toDict()
 
         # Store the configuration
         self.__configurators['cors'] = cors
@@ -1108,7 +1146,9 @@ class Application(Container, IApplication):
 
         # If database is a dict, convert it to Database instance
         if isinstance(database, dict):
-            database = Database(**database)
+            database = Database(**database).toDict()
+        elif isinstance(database, Database):
+            database = database.toDict()
 
         # Store the configuration
         self.__configurators['database'] = database
@@ -1194,7 +1234,9 @@ class Application(Container, IApplication):
 
         # If filesystems is a dict, convert it to Filesystems instance
         if isinstance(filesystems, dict):
-            filesystems = Filesystems(**filesystems)
+            filesystems = Filesystems(**filesystems).toDict()
+        elif isinstance(filesystems, Filesystems):
+            filesystems = filesystems.toDict()
 
         # Store the configuration
         self.__configurators['filesystems'] = filesystems
@@ -1280,7 +1322,9 @@ class Application(Container, IApplication):
 
         # If logging is a dict, convert it to Logging instance
         if isinstance(logging, dict):
-            logging = Logging(**logging)
+            logging = Logging(**logging).toDict()
+        elif isinstance(logging, Logging):
+            logging = logging.toDict()
 
         # Store the configuration
         self.__configurators['logging'] = logging
@@ -1366,7 +1410,9 @@ class Application(Container, IApplication):
 
         # If mail is a dict, convert it to Mail instance
         if isinstance(mail, dict):
-            mail = Mail(**mail)
+            mail = Mail(**mail).toDict()
+        elif isinstance(mail, Mail):
+            mail = mail.toDict()
 
         # Store the configuration
         self.__configurators['mail'] = mail
@@ -1377,8 +1423,7 @@ class Application(Container, IApplication):
     def setPaths(
         self,
         *,
-        root: str | Path = Path.cwd().resolve(),
-        commands: str | Path = (Path.cwd() / 'app' / 'console' / 'commands').resolve(),
+        console: str | Path = (Path.cwd() / 'app' / 'console').resolve(),
         controllers: str | Path = (Path.cwd() / 'app' / 'http' / 'controllers').resolve(),
         middleware: str | Path = (Path.cwd() / 'app' / 'http' / 'middleware').resolve(),
         requests: str | Path = (Path.cwd() / 'app' / 'http' / 'requests').resolve(),
@@ -1415,8 +1460,6 @@ class Application(Container, IApplication):
 
         Parameters
         ----------
-        root : str or Path, optional
-            Root directory of the application. Defaults to the current working directory.
         commands : str or Path, optional
             Directory for console command classes. Defaults to 'app/console/commands'.
         controllers : str or Path, optional
@@ -1483,8 +1526,8 @@ class Application(Container, IApplication):
         # Prepare and store all resolved paths as strings in the configurators dictionary
         # Ensure 'paths' exists in configurators
         self.__configurators['path'] = {
-            'root' : str(root),
-            'commands' : str(commands),
+            'root' : self.__bootstrap_base_path or str(Path.cwd().resolve()),
+            'console' : str(console),
             'controllers' : str(controllers),
             'middleware' : str(middleware),
             'requests' : str(requests),
@@ -1555,7 +1598,15 @@ class Application(Container, IApplication):
 
         # If paths is a dict, convert it to Paths instance
         if isinstance(paths, dict):
-            paths = Paths(**paths)
+            paths.update({
+                'root': self.__bootstrap_base_path or str(Path.cwd().resolve())
+            })
+            paths = Paths(**paths).toDict()
+        elif isinstance(paths, Paths):
+            paths = paths.toDict()
+            paths.update({
+                'root': self.__bootstrap_base_path or str(Path.cwd().resolve())
+            })
 
         # Store the configuration
         self.__configurators['path'] = paths
@@ -1563,6 +1614,52 @@ class Application(Container, IApplication):
         # Return the application instance for method chaining
         return self
 
+    def setBasePath(
+        self,
+        basePath: str | Path
+    ) -> 'Application':
+        """
+        Set the base path for the application.
+
+        This method allows setting the base path of the application, which is
+        used as the root directory for all relative paths in the application.
+        The provided basePath is resolved to an absolute path.
+
+        Parameters
+        ----------
+        basePath : str or Path
+            The base path to set for the application. It can be a string or a Path object.
+
+        Returns
+        -------
+        Application
+            The current application instance to enable method chaining.
+        """
+
+        # Resolve and store the base path as a string
+        self.__bootstrap_base_path = str(Path(basePath).resolve())
+
+        # Return self instance for method chaining
+        return self
+
+    def getBasePath(
+        self
+    ) -> str | Path:
+        """
+        Get the base path of the application.
+
+        This method returns the base path that was previously set using setBasePath().
+        If no base path has been set, it returns None.
+
+        Returns
+        -------
+        str or Path
+            The base path of the application as a string or Path object, or None if not set.
+        """
+
+        # Return the base path if set, otherwise None
+        return self.__bootstrap_base_path if self.__bootstrap_base_path else Path.cwd().resolve()
+
     def setConfigQueue(
         self,
         **queue_config
@@ -1641,7 +1738,9 @@ class Application(Container, IApplication):
 
         # If queue is a dict, convert it to Queue instance
         if isinstance(queue, dict):
-            queue = Queue(**queue)
+            queue = Queue(**queue).toDict()
+        elif isinstance(queue, Queue):
+            queue = queue.toDict()
 
         # Store the configuration
         self.__configurators['queue'] = queue
@@ -1727,7 +1826,9 @@ class Application(Container, IApplication):
 
         # If session is a dict, convert it to Session instance
         if isinstance(session, dict):
-            session = Session(**session)
+            session = Session(**session).toDict()
+        elif isinstance(session, Session):
+            session = session.toDict()
 
         # Store the configuration
         self.__configurators['session'] = session
@@ -1813,7 +1914,9 @@ class Application(Container, IApplication):
 
         # If testing is a dict, convert it to Testing instance
         if isinstance(testing, dict):
-            testing = Testing(**testing)
+            testing = Testing(**testing).toDict()
+        elif isinstance(testing, Testing):
+            testing = testing.toDict()
 
         # Store the configuration
         self.__configurators['testing'] = testing
